class AccountApiUrl:
    ACCOUNTS = "/api/v2/accounts"
    ACCOUNTS_V3 = "/api/v3/accounts"
    ACCOUNT_INFORMATION = "/api/v3/accounts/{id}/information"
    ACCOUNT_CANCEL = "/api/v3/accounts/{id}/cancel"
    ACCOUNT_REACTIVATE = "/api/v2/accounts/{id}/reactivate"
    ACCOUNT_REACTIVATE_V3 = "/api/v3/accounts/{id}/reactivate"
    ACCOUNT_UPDATE_INFORMATION = "/api/v3/accounts/{id}/information"
    ACCOUNT_DELETE = "/api/v3/accounts/{id}"
    ACCOUNT_CONTACTS = "/api/v3/accounts/{id}/contacts"
    ACCOUNT_CONTACT_TYPE = "/api/v3/accounts/{id}/contacts/{contact_type}"
    ACCOUNT_CONTACT_UPDATE = "/api/v2/accounts/{id}/contacts/{contact_type}"
    ACCOUNT_CONTACT_UPDATE_V3 = "/api/v3/accounts/{id}/contacts/{contact_type}"
    ACCOUNT_CONTACT_DELETE = "/api/v3/accounts/{id}/contacts/{contact_type}"
    ACCOUNT_PAYMENT_METHODS = "/api/v2/accounts/{id}/payment-methods"
    ACCOUNT_PAYMENT_METHODS_V3 = "/api/v3/accounts/{id}/payment-methods"
    EACH_PAYMENT_METHODS = "/api/v2/accounts/{id}/payment-methods/{reference}"
    EACH_PAYMENT_METHODS_V3 = "/api/v3/accounts/{id}/payment-methods/{reference}"
    ACCOUNT_BILLING_PREFERENCE = "/api/v3/accounts/{id}/billing-preferences"
    ACCOUNT_ADDRESSES = "/api/v3/accounts/{id}/addresses"
    ACCOUNT_PAYMENT_METHODS_UPDATE = "/api/v3/accounts/{id}/payment-methods/{reference}"
    ACCOUNT_CONTACT_MODIFY = "/api/v3/accounts/{id}/contacts/{contact_type}"
    ACCOUNTS_ADDRESS = "/api/v3/accounts/{id}/addresses"
    ACCOUNTS_NOTE = "/api/v3/accounts/{id}/notes"
    ACCOUNTS_ADDRESS_UUID = "/api/v3/accounts/{id}/addresses/{uuid}"
    ACCOUNTS_NOTE_UUID = "/api/v3/accounts/{id}/notes/{uuid}"
    ACCOUNTS_NOTE_UUID_FILES = "/api/v3/accounts/{id}/notes/{uuid}/files"
    ACCOUNTS_NOTE_UUID_FILES_UUID = "/api/v3/accounts/{id}/notes/{uuid}/files/{file_uuid}"
    ACCOUNTS_IMAGE = "/api/v3/accounts/{id}/image"
    ACCOUNT_SENT_EMAIL = "/api/v3/accounts/{id}/communications/emails"
    ACCOUNT_SENT_EMAIL_UUID = "/api/v3/accounts/{id}/communications/emails/{uuid}"
