class OrderApiUrl:
    ORDERS = "/api/v2/orders"
    ORDER_CANCEL = "/api/v2/orders/{id}/cancel"
    USAGE_ADD = "/api/v3/usages"
    CONTRACT_ORDER_CREATE = "/api/v2/orders"
    ORDER_REACTIVATE = "/api/v2/orders/{id}/reactivate"
    ORDER_PREORDER = "/api/v2/orders/preorder"
    ORDER_CHANGE = "/api/v2/orders/{id}/change"
    ORDER_DELETE = "/api/v3/orders/{id}"
    ORDER_QUOTE_PDF = "api/v2/orders/{id}/pdf"
    ORDER_INFORMATION = "/api/v3/orders/{id}/information"
    ORDER_BILLING_PREFERENCES = "/api/v3/orders/{id}/billing-preferences"
    ORDER_LINES = "/api/v3/orders/{id}/lines"
    ORDER_LINES_CHARGE = "/api/v3/orders/{id}/lines/{uuid}"
    ORDERS_ACCOUNT = "/api/v3/accounts/{id}/orders"
    ORDER_UPGRADE = "/api/v2/orders/{id}/upgrade"
    CONTRACT_ADJUSTMENT = "/api/v2/orders/{id}/contract-adjustment/preview"
    ORDER_UPGRADE_PREVIEW = "/api/v2/orders/{id}/upgrade/preview"
    ORDER_DOWNGRADE = "/api/v2/orders/{id}/downgrade"
    ORDER_DOWNGRADE_PREVIEW = "/api/v2/orders/{id}/downgrade/preview"
    ORDER_LINES_INFORMATION = "/api/v3/orders/{id}/lines/{uuid}/information"
    ORDER_RELINQUISH = "/api/v3/orders/{id}/relinquish"
    CONTRACT_ORDER_CREATE ="/api/v2/orders"
    USAGE_LIST = "/api/v3/usages"
    USAGE_DETAILS = "/api/v3/usages"
    USAGE_MODIFY = "/api/v3/usages/{uuid}"
    USAGE_UPDATE = "/api/v2/usages/{uuid}"
    USAGE_DELETE = "/api/v3/usages/{uuid}"
    PAYMENT_METHODS = "/api/v3/orders/{id}/payment-methods"


    # Purchase Order URLS
    PURCHASE_ORDER_CREATE = "/api/v3/orders"
