class SettingApiUrl:
    SETTINGS = "/api/v3/settings"
    SETTINGS_PAYMENT_PROCESSOR = "/api/v2/settings/payment_processors"
    SETTINGS_PRICING_LEVELS = "/api/v3/settings/pricing_levels"
    SETTINGS_ITEM_GROUPS = "/api/v3/settings/item_groups"
    SETTINGS_CURRENCIES = "/api/v3/settings/currencies"
    SETTINGS_TAXES = "/api/v2/settings/taxes"
    SETTINGS_WAREHOUSES = "/api/v2/settings/warehouses"
    SETTINGS_COMPONENT = "/api/v2/settings/components"
    SETTINGS_SHIPPING_PROFILES = "/api/v2/settings/shipping-profiles"
    SETTINGS_VARIATIONS = "/api/v2/settings/variations"
    SETTINGS_VARIATIONS_CREATE = "/api/v2/settings/variations"
    SETTINGS_VARIATIONS_UPDATE = "/api/v2/settings/variations/{uuid}"
    SETTINGS_DISCOUNT_PROFILES = "/api/v2/settings/discount_profiles"